@@ -4,6 +4,11 @@
 // @require       google-common.js
 // ==/UserScript==
 
+// This placeholder gets munged with real data at build time.
+var WebappsGettextDict = JSON.parse(unescape(
+    "%7B%22GETTEXT%22%3A%22PLACEHOLDER%22%7D"
+));
+
 window.Unity = external.getUnityObject(1);
 
 function isCorrectPage() {
